@@ -75,9 +75,10 @@ def main():
                 command = getattr(manager, command)
                 if callable(command):
                     gen = command(*args)
-                    if gen:
+                    try:
                         for vals in gen:
                             print('\t'.join(vals))
+                    except Exception: pass
                 else:
                     print(command)
             return
